# Sass (Sass)

To use this language, use the class "language-sass".

## Comments

    /* This comment will appear in the CSS output.
      This is nested beneath the comment,
      so it's part of it

    // This comment will not appear in the CSS output.
      This is nested beneath the comment as well,
      so it also won't appear

## At-rules and shortcuts

    @mixin large-text
      color: #ff0000

    @media (min-width: 600px)
      h1
        @include large-text

    =large-text
      color: #ff0000

    h1
      +large-text

## Variables

    $width: 5em
    #main
      width: $width

## Known failures

There are certain edge cases where Prism will fail. There are always such cases in every regex-based syntax highlighter. However, Prism dares to be open and honest about them. If a failure is listed here, it doesn’t mean it will never be fixed. This is more of a “known bugs” list, just with a certain type of bug.

### Deprecated Sass syntax is not supported

    .page
      color = 5px + 9px

    !width = 13px
    .icon
      width = !width

### Selectors with pseudo classes are highlighted as property/value pairs

    a:hover
      text-decoration: underline